@@ -7,10 +7,10 @@ import click
 
 from mldock.__version__ import __version__
 from mldock.__init__ import MLDOCK_LOGO
-# from mldock.command.initialize import init
 from mldock.command.container import container
+from mldock.command.configure import configure
 from mldock.command.local import local
-from mldock.command.cloud import cloud
+from mldock.command.registry import registry
 from mldock.log import configure_logger
 
 click.disable_unicode_literals_warning = True
@@ -23,19 +23,20 @@ CLI_VERSION = 'Version: cli {}'.format(__version__)
 @click.pass_context
 def cli(ctx, verbose):
     """
-    A CLI that helps put machine learning in places that empower data scientists.
+    A CLI that helps put machine learning in places that empower ml developers
     """
-    _FILE_DIR_PATH = os.path.dirname(os.path.realpath(__file__))
+    mldock_package_path = os.path.dirname(os.path.realpath(__file__))
     logger=configure_logger('mldock', verbose=verbose)
     logger.info(MLDOCK_LOGO)
     logger.info(CLI_VERSION)
-    ctx.obj = {'verbose': verbose, 'helper_library_path':_FILE_DIR_PATH, 'logo':MLDOCK_LOGO}
+    ctx.obj = {'verbose': verbose, 'mldock_package_path': mldock_package_path, 'logo': MLDOCK_LOGO}
 
 def add_commands(cli):
 
+    cli.add_command(configure)
     cli.add_command(container)
     cli.add_command(local)
-    cli.add_command(cloud)
+    cli.add_command(registry)
 
 add_commands(cli)
 
