@@ -73,10 +73,9 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
     mldock_package_path=obj['mldock_package_path']
     try:
         click.secho("Initializing MLDock project configuration", bg='blue', nl=True)
-        prompt_input = click.confirm("File not found. Create?")
         mldock_manager = MLDockConfigManager(
             filepath=os.path.join(dir, ".mldock.json"),
-            create=prompt_input
+            create=True
         )
         if not no_prompt:
             mldock_manager.setup_config()
