@@ -5,14 +5,15 @@ import os
 import sys
 import json
 import argparse
-import logging
 import pickle
 
-from mldock.platform_helpers import environment as mldock_environment
-import logging
+import pandas as pd
+from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import StandardScaler
+from sklearn.model_selection import cross_val_score
+from sklearn.svm import SVC
 
-logging.basicConfig(level=logging.DEBUG)
-logger = logging.getLogger('mldock')
+from src.container.assets import environment, logger
 
 def str2bool(arg_value: str) -> bool:
     if isinstance(arg_value, bool):
@@ -33,17 +34,12 @@ def str2dict(arg_value: str) -> dict:
 
 def run_training():
 
-    environment = mldock_environment.Environment(base_dir='/opt/ml/')
-
     PARSER= argparse.ArgumentParser()
     ## User set params which link to Sagemaker params
-    PARSER.add_argument('--lookup', type=str,
-                        default=os.path.join(environment.input_data_dir, 'lookup'),
+    PARSER.add_argument('--iris', type=str,
+                        default=os.path.join(environment.input_data_dir, 'iris'),
                         help='Expects a .csv file, representing the lookup.')
-    PARSER.add_argument('--detail', type=str,
-                        default=os.path.join(environment.input_data_dir, 'detail'),
-                        help='Expects a .csv file, representing the detail.')
-    PARSER.add_argument('--factors', default=environment.hyperparameters.get('factors', 20),
+    PARSER.add_argument('--test-size', default=environment.hyperparameters.get('test-size', 0.2),
                         type=int,
                         help='Number of factorization factors to compute during model fit.')
     PARSER.add_argument('--regularization', default=environment.hyperparameters.get('regularization', 0.3),
@@ -62,30 +58,45 @@ def run_training():
     # Get args
     ARGS, _ = PARSER.parse_known_args()
 
-
     logger.info("Experiment id = {}".format(environment.environment_variables('MLDOCK_EXPERIMENT_ID', default=None)))
+
+    data = pd.read_csv(os.path.join(ARGS.iris, 'train.csv'))
+    X, y = data.drop(['target'], axis=1), data['target']
+    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=ARGS.test_size, random_state=123, shuffle=True)
+
+    transformer = StandardScaler()
+    transformer.fit(X_train)
+    X_train_std = transformer.transform(X_train)
+    X_test_std = transformer.transform(X_test)
+
     if ARGS.run_eval:
         logger.info('Running Evaluation')
-        # TODO Add your Evaluation Fitting here
-        logger.info("Data found at {}\n{}".format(ARGS.lookup, os.listdir(ARGS.lookup)))
-        logger.info("Some hyperparameters = factors={}, regularization={}, iterations={}".format(ARGS.factors, ARGS.regularization, ARGS.iterations))
 
+        model = SVC(kernel='rbf', random_state=0, gamma=.10, C=1.0)
+        model.fit(X_train_std, y_train)
+
+        print('Model: Accuracy (train) {:.2f}'.format(model.score(X_train_std, y_train)))
+        print('Model: Accuracy (test) {:.2f}'.format(model.score(X_test_std, y_test)))
 
-    # save model to s3
     if ARGS.refit:
         logger.info('Refitting Final Model')
-        # TODO Add model.fit(X) here again
 
+        transformer = StandardScaler()
+        transformer.fit(X)
+        X_std = transformer.transform(X)
+        model = SVC(kernel='rbf', random_state=0, gamma=.10, C=1.0)
+        model.fit(X_std, y)
 
-        # save model to s3
-        logger.info("Model saved in {}. This is written back to s3 at job completion.".format(environment.model_dir))
-        model_path = os.path.join(environment.model_dir, 'model.pkl')
-        # TODO add model saving workflow here
+        logger.info("Model saved in {}. This is written back to remote at job completion.".format(environment.model_dir))
+        transformer_path = os.path.join(environment.model_dir, 'iris/transformer.pkl')
 
-        model_fake = { "lion": "yellow", "kitty": "red" }
+        with open(transformer_path, 'wb') as file_:
+            pickle.dump(transformer, file_)
+
+        model_path = os.path.join(environment.model_dir, 'iris/model.pkl')
 
         with open(model_path, 'wb') as file_:
-            pickle.dump(model_fake, file_)
+            pickle.dump(model, file_)
     else:
         logger.debug("Skipping model save step. ")
 
