@@ -6,8 +6,9 @@ import sys
 import json
 import argparse
 import logging
+
 # Add sagemaker environment in training
-from mldock.platform_helpers.aws.sagemaker import environment as sagemaker_environment
+from src.container.assets import environment, logger
 
 def str2bool(arg_value: str) -> bool:
     if isinstance(arg_value, bool):
@@ -27,17 +28,11 @@ def str2dict(arg_value: str) -> dict:
         raise argparse.ArgumentTypeError('Json Dictionary expected.')
 
 def run_training():
-    logging.basicConfig(level=logging.INFO)
-    logger = logging.getLogger('sagemaker')
-    logger.setLevel(logging.INFO)
-
-    environment = sagemaker_environment.Environment()
-
     PARSER= argparse.ArgumentParser()
     ## User set params which link to Sagemaker params
-    PARSER.add_argument('--training', type=str,
-                        default=environment.channel_input_dirs["training"],
-                        help='Expects a s3 path to directory containing a sparse .npz file containing item user matrix')
+    PARSER.add_argument('--iris', type=str,
+                        default=environment.channel_input_dirs["iris"],
+                        help='Path to data')
     PARSER.add_argument('--factors', default=environment.hyperparameters.get('factors', 20),
                         type=int,
                         help='Number of factorization factors to compute during model fit.')
@@ -61,7 +56,7 @@ def run_training():
         logger.info('Running Evaluation')
         # TODO Add your Evaluation Fitting here
         
-        logger.info("Your data is here = {}".format(ARGS.training))
+        logger.info("Your data is here = {}".format(ARGS.iris))
 
         logger.info("Some hyperparameters = factors={}, regularization={}, iterations={}".format(ARGS.factors, ARGS.regularization, ARGS.iterations))
 
@@ -79,10 +74,3 @@ def run_training():
         pass
     else:
         logger.info("Skipping model save step. ")
-
-if __name__ == '__main__':
-
-    try:
-        run_training()
-    except Exception as exception:
-        logger.error(exception)
